#!/usr/bin/python
# -*- coding: utf-8 -*-
# wlcCommon.py, common functions
# see README for more info
# The source code is distributed under GPLv3 license
import os
import fnmatch
import sqlite3

# recurse directory and yeild file matched
def find_files(directory, pattern):
    for root, dirs, files in os.walk(directory):
        for basename in files:
            if fnmatch.fnmatch(basename, pattern):
                fname = os.path.join(root, basename)
                yield fname

# translation charmaps
# format: {diphtongs}, {simple translations}, {chars with several transcodes}...
cyr = (
    {u'ьо': u'io', u'юй': u'yuy', u'ия': u'ia'},
    {
    u'а': u'a',  u'б': u'b',  u'в': u'v',  u'г': u'g', u'д': u'd', u'е': u'e',
    u'ё': u'yo', u'ж': u'zh', u'з': u'z',  u'и': u'i', u'й': u'i', u'к': u'k',
    u'л': u'l',  u'м': u'm',  u'н': u'n',  u'о': u'o', u'п': u'p', u'р': u'r',
    u'с': u's',  u'т': u't',  u'у': u'u',  u'ф': u'f', u'х': u'h', u'ц': u'c',
    u'ъ': u'a',  u'ы': u'y',  u'ь': u'',   u'э': u'e', u'ю': u'yu',u'я': u'ia'
    }, {
    u'ч': u'ch', u'ш': u'sh', u'щ': u'sht'
    }, {
    u'ч': u'4', u'ш': u'6', u'щ': u'6t'
    })

# do transcode
def trans(instr):
    HasSpecials = False
    first = instr
    for diphthong, value in cyr[0].items():
        first = first.replace(diphthong, value)
    
    second = u''
    for char in first:
        second += cyr[1].get(char, char)
        if char in cyr[2]:
            HasSpecials = True

    if HasSpecials:
        for i in range(2, len(cyr)):
            third = second
            for special, value in cyr[i].items():
                third = third.replace(special, value)
            yield third
    else:
        yield second

#convert bytes to b/K/M/G/T
def convert_bytes(bytes):
    bytes = float(bytes)
    if bytes >= 1099511627776:
        terabytes = bytes / 1099511627776
        size = '%.2fT' % terabytes
    elif bytes >= 1073741824:
        gigabytes = bytes / 1073741824
        size = '%.2fG' % gigabytes
    elif bytes >= 1048576:
        megabytes = bytes / 1048576
        size = '%.2fM' % megabytes
    elif bytes >= 1024:
        kilobytes = bytes / 1024
        size = '%.2fK' % kilobytes
    else:
        size = '%.2fb' % bytes
    return size

#Write dict in sqlite3 db
def writeDB(dbfile, wl):
    conn = sqlite3.connect(dbfile)
    c = conn.cursor()
    c.execute('CREATE TABLE IF NOT EXISTS wl (word TEXT PRIMARY KEY, freq INTEGER NOT NULL)')
    c.execute('PRAGMA synchronous=OFF')
    c.execute('PRAGMA count_changes=OFF')
    c.execute('PRAGMA journal_mode=MEMORY')
    c.execute('PRAGMA temp_store=MEMORY')
    for pair in wl:
        c.execute('INSERT OR IGNORE INTO wl VALUES (:word, :count)', (pair, wl[pair],))
    c.execute('VACUUM')
    conn.close()
