#!/usr/bin/python
# -*- coding: utf-8 -*-
# wlc-wp.py, wordlist creator Wikipedia edition
# extracts words from xml.bz2 backups of Wikipedia, transcode and put in sqlitedb
# see README for more info
# The source code is distributed under GPLv3 license
import os
import re
import bz2
import datetime
from optparse import OptionParser
from wlCommon import *

print 'Wordlist creator Wikipedia edition v0.1 by Alex Stanev'

# play with options
usage = '%prog [options]'

parser = OptionParser(usage=usage)
parser.add_option('-l', '--lang', dest='lang', type='string',
                default='en', help='Input files charset [default: %default]')
parser.add_option('-d', '--database', dest='db', type='string',
                default='wlc.db', help='Output sqlite3 db [default: %default]')
parser.add_option('-t', '--translate', dest='translate', type='string',
                default='off', help='Transcode cyr char to en [default: %default]')
parser.add_option('-p', '--path', dest='path', type='string',
                help='Path to xml.bz2 where wp dump live')

(options, args) = parser.parse_args()
if not options.path:
    parser.error('no path specified')
if not os.path.exists(options.path):
    parser.error('path not found')

lang = options.lang

dbfile = options.db
dpath = options.path

if options.translate == 'on':
    translate = True
else:
    translate = False

if lang == 'bg':
    stripall = re.compile(u'[^а-я\s]+')
else:
    stripall = re.compile(u'[^a-z\s]+')

striphtml = re.compile(u'<.*?>')
stripwc   = re.compile(u'\[.*?\]')
stripcb   = re.compile(u'\{.*?\}')

nowmin = datetime.datetime.now()
wpfile = bz2.BZ2File(dpath, 'r')
lastpos = wpfile.tell()
wl = {}
while True:
    lines = wpfile.readlines(1024*1024)
    if len(lines) == 0:
        break
    cont = ''.join(lines)
    now = datetime.datetime.now()
    if now.minute != nowmin:
        nowmin = now.minute
        newpos = wpfile.tell()
        print 'Processed size %s perf: %s/s' %( convert_bytes(newpos), convert_bytes((newpos-lastpos)/60))
        lastpos = newpos
    cont = striphtml.sub(' ', cont)
    cont = stripwc.sub(' ', cont)
    cont = stripcb.sub(' ', cont)
    cont = cont.lower()
    cont = stripall.sub(' ', cont)
    cont = cont.strip()
    if cont == '':
        continue
    words = cont.split()

    for word in words:
        if translate:
            for tword in trans(word):
                if tword in wl:
                    wl[tword] += 1
                else:
                    wl[tword] = 1
        else:
            if word in wl:
                wl[word] += 1
            else:
                wl[word] = 1
wpfile.close()

print 'Writting to db...'
writeDB(dbfile, wl)

print 'End'
