#!/usr/bin/python
# -*- coding: utf-8 -*-
# wlc.py, wordlist creator
# extracts words from txt/html files, transcode and put in sqlitedb
# see README for more info
# The source code is distributed under GPLv3 license
import os
import re
from optparse import OptionParser
from wlCommon import *

print 'Wordlist creator v0.2 by Alex Stanev'

# play with options
usage = '%prog [options]'

parser = OptionParser(usage=usage)
parser.add_option('-l', '--lang', dest='lang', type='string',
                default='en', help='Input files charset [default: %default]')
parser.add_option('-s', '--strip-html', dest='strip_html', type='string',
                default='off', help='Strip html tags [default: %default]')
parser.add_option('-d', '--database', dest='db', type='string',
                default='wlc.db', help='Output sqlite3 db [default: %default]')
parser.add_option('-g', '--glob', dest='pattern', type='string',
                default='txt', help='File pattern to [default: %default]')
parser.add_option('-t', '--translate', dest='translate', type='string',
                default='off', help='Transcode cyr char to en [default: %default]')
parser.add_option('-p', '--path', dest='path', type='string',
                help='Path to directory where texts live')
(options, args) = parser.parse_args()
if not options.path:
    parser.error('no path specified')
if not os.path.exists(options.path):
    parser.error('path not found')

lang = options.lang

dbfile = options.db
fpattern = '*.'+options.pattern
dpath = options.path

if options.strip_html == 'on':
    strip = True
else:
    strip = False

if options.translate == 'on':
    translate = True
else:
    translate = False

if lang == 'bg':
    stripall = re.compile(u'[^а-я\s]+')
else:
    stripall = re.compile(u'[^a-z\s]+')
if strip:
    striphtml = re.compile(u'<.*?>')

wl  = {}
cnt = 0
for filename in find_files(dpath, fpattern):
    cnt += 1
    print("Processing file(%d): %s" %(cnt, filename))
    infile = open(filename)
    cont = infile.read()
    infile.close()
    try:
        cont = cont.decode('utf-8')
    except:
        continue
    if strip:
        cont = striphtml.sub(' ', cont)
    cont = cont.lower()
    cont = stripall.sub(' ', cont)
    cont = cont.strip()
    if cont == '':
        continue
    words = cont.split()
    for word in words:
        if translate:
            for tword in trans(word):
                if tword in wl:
                    wl[tword] += 1
                else:
                    wl[tword] = 1
        else:
            if word in wl:
                wl[word] += 1
            else:
                wl[word] = 1

print 'Writting to db...'
writeDB(dbfile, wl)

print 'End'
